// Copyright 2017 Google Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.webauthn.gaedemo.servlets;

import com.google.appengine.api.users.User;
import com.google.appengine.api.users.UserService;
import com.google.appengine.api.users.UserServiceFactory;
import com.google.webauthn.gaedemo.service.UserProxyService;
import com.google.webauthn.gaedemo.storage.Credential;
import java.io.IOException;
import java.util.List;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Servlet implementation class RemoveCredential
 */
public class RemoveCredential extends HttpServlet {
  private static final long serialVersionUID = 1L;
  private final UserService userService = UserServiceFactory.getUserService();

  /**
   * @see HttpServlet#HttpServlet()
   */
  public RemoveCredential() {}

  /**
   * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
   */
  @Override
  protected void doGet(HttpServletRequest request, HttpServletResponse response)
      throws ServletException, IOException {
    /* Tyler start -----------------*/
    UserProxyService userProxyService = UserProxyService.getInstance();
    User user = userProxyService.getCurrentUser();
    String currentUser = user.getEmail();
    /* Tyler end -----------------*/
    /* Original code
    String currentUser = userService.getCurrentUser().getEmail();
     */
    Credential.remove(currentUser, request.getParameter("id"));


    List<Credential> savedCreds = Credential.load(currentUser);

    response.setContentType("text/html");
    for (Credential c : savedCreds) {
      response.getWriter()
          .println(c.toJson() + "<a href=RemoveCredential?id=" + c.id + ">[X]</a><br />");
    }
  }

  /**
   * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
   */
  @Override
  protected void doPost(HttpServletRequest request, HttpServletResponse response)
      throws ServletException, IOException {
    String currentUser = userService.getCurrentUser().getEmail();
    Credential.remove(currentUser, request.getParameter("credentialId"));

    response.setContentType("application/json");
    response.getWriter().println("{}");
  }

}
